@@ -43,6 +43,8 @@ import threading
 from threading import Thread
 import glob
 import re
+import logging
+import time
 import xml.etree.ElementTree as ET
 sns.set(color_codes=True)
 
@@ -1199,19 +1201,56 @@ class VectorsInternalSplitedDataReader:
         return result
 
 class LargeFileWriter:
-    def _create_block_file(self, data,prefix,index, directory_path, ext):
+    def __init__(self, directory_path):
+        #self.logger = logger
+        self.directory_path = directory_path
+        self.REFERENCE_FILE = "reference.ref"
+        self.REFERENCE_FILE_FINISHED = "finished"
+        self.REFERENCE_FILE_NOT_FINISHED = "not finished"
+
+    def _log(self, message):
+        local_log_file = os.path.join(self.directory_path, "logfile.log")
+        with open(local_log_file, "a") as myfile:
+            myfile.write("\n" + time.strftime("%b %d %Y %H:%M:%S - ") +  message)
+            
+    def _create_block_file(self, data, index, ext, total_file):
         
         if "." in ext:
             ext = ext.replace(".", "")
 
-        file = os.path.join(directory_path, "{0}_block_{1}.{2}".format(prefix, index, ext))
+        file = os.path.join(self.directory_path, "block_{0}.{1}".format(index, ext))
+        #if not os.path.isfile(file):
+        self._log("{0} beggin".format(file)) 
         joblib.dump(data, file)
-        print(file, " finished!")
+        self._log("{0} finished".format(file))
+        #print(file, " finished!")
+        
+        #reference_file = os.path.join(directory_path, self.REFERENCE_FILE)
+        #if not os.path.isfile(reference_file):
+        #    with open(reference_file, 'w') as fp:
+        #        pass
+        #block_files = [f for f in os.listdir(directory_path) if re.match(r'block_[0-9]+.*', f)]
+        #fileWriter = open(reference_file,"w") 
+        #if len(block_files) == total_file:
+        #    fileWriter.write("len(block_files) == total_file : {0} == {1} ".format(len(block_files), total_file))
+        #    #fileWriter.write(self.REFERENCE_FILE_FINISHED)
+        #else:
+        #    fileWriter.write("len(block_files) == total_file : {0} == {1} ".format(len(block_files), total_file))
+        #    #fileWriter.write(self.REFERENCE_FILE_FINISHED)
+        #fileWriter.close()      
     
-    def write(self, data_list,prefix,directory_path, ext):
+    def to_continue(self, directory_path):
+        reference_file = os.path.join(directory_path, self.REFERENCE_FILE)
+        fileWriter = open(reference_file,"r+")
+        value = fileWriter.read()
+        return value == self.REFERENCE_FILE_NOT_FINISHED
+
+
+    def write(self, data_list, ext):
         threadlist = []
+        print("len(data_list) : ", len(data_list))
         for index, data in enumerate(data_list):
-            t = Thread(target=self._create_block_file, args=(data, prefix,index, directory_path, ext))
+            t = Thread(target=self._create_block_file, args=(data, index, ext, len(data_list)))
             threadlist.append(t)
 
         for _thread in threadlist:
@@ -1220,6 +1259,3 @@ class LargeFileWriter:
         for _thread in threadlist:
             _thread.join()
 
-    #def read(self, directory_path, prefix, ext):
-    #    files = [f for f in os.listdir(directory_path) if re.match(r'^.*_block_[0-9]+.*', f)]
-
